# ramem

[![PyPI - Version](https://img.shields.io/pypi/v/ramem.svg)](https://pypi.org/project/ramem)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/ramem.svg)](https://pypi.org/project/ramem)

-----

Under construction...

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install ramem
```

## License

`ramem` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
